# Cybrex AI

Cybrex AI integrates several strategies to use AI for facilitating navigation through science:

- IPFS is utilized to access the Standard Template Construct (STC).
- STC provides the raw documents for Cybrex.
- Embedding Model (OpenAI or Instructor-XL) constructs embeddings for these documents and Cybrex stores these embeddings locally in the Chroma database.
- These embeddings are then used to filter relevant documents before they are sent to LLM (Open AI, WizardLM or any other one) for Q&A and summarization.

## Install

You should have [installed IPFS](http://standard-template-construct.org/#/help/install-ipfs)

```bash
pip install cybrex
```

Upon its initial launch, `cybrex` will create a `~/.cybrex` directory containing a `config.yaml` file and a `chroma` directory.
You can edit the config file to point to different IPFS addresses.

## Usage

```bash
# Summarize a document
cybrex sum-doc --field doi --value 10.1155/2022/7138756

# Question a document
cybrex chat-doc --field doi --value 10.1155/2022/7138756 \
  --question "What is the antivirus effect of resveratrol?"
  
# Question science
cybrex chat-sci --question "What is the antivirus effect of resveratrol?"
```
